# -*- coding: utf-8 -*-
#
#    Copyright 2019 Fabien Bourgeois <fabien@yaltik.com>
#    Copyright 2019 Youssef El Ouahby <youssef@yaltik.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

""" GOLEM Activity Registration Analysis Wizard Management """

import logging
from odoo import models, fields, api, _
from odoo.exceptions import UserError, ValidationError
_LOGGER = logging.getLogger(__name__)


class GolemActivityRegistrationAnalysisWizard(models.TransientModel):
    """ GOLEM Activity Registration Analysis Wizard Management  """
    _name = 'golem.activity.registration.analysis.wizard'
    _description = 'GOLEM Activity Registration Analysis Wizard Management '

    season_id = fields.Many2one('golem.season', 'Season', required=True)
    analyse_type = fields.Selection(
        [
            ('age_start_activity_area', 'By age at season start and area and activity'),
            ('age_end_activity_area', 'By age at season end and area and activity')
            ],
        required=True)

    @api.multi
    def get_pivot_view(self):
        self.ensure_one()
        rec = self[0]
        if rec.analyse_type == 'age_start_activity_area':
            return self.env.ref(
                'golem_activity_registration.golem_member_analysis_pivot_age_start_activity_area',
                False)
        elif rec.analyse_type == 'age_end_activity_area':
            return self.env.ref(
                'golem_activity_registration.golem_member_analysis_pivot_age_end_activity_area',
                False)


    @api.multi
    def registration_analye(self):
        self.ensure_one()
        analysis_rec = self[0]
        registrations = self.env['golem.activity.registration'].search(
            [('season_id', '=', analysis_rec.season_id.id)]
            )
        self.env['golem.member.analysis'].search([]).unlink()
        if registrations:
            for registration in registrations:
                self.env['golem.member.analysis'].create({
                    'season_id': analysis_rec.season_id.id,
                    'member_id': registration.member_id.id,
                    'activity_id': registration.activity_id.id
                    })
            analyse_pivot = analysis_rec.get_pivot_view()
            return {
                'name': _('Member Analysis'),
                'type': 'ir.actions.act_window',
                'res_model': 'golem.member.analysis',
                'view_type': 'pivot',
                'view_mode': 'pivot',
                #'views': [(analyse_pivot.id, 'form')],
                'view_id': analyse_pivot.id,
                'target': 'new',
            }
